@@ -388,9 +388,8 @@ impl ProfilerUi {
             frame.num_bytes as f64 * 1e-3
         ));
 
-        if frame.thread_streams.len() > 1 {
-            self.options.sorting.ui(ui);
-        }
+        // The number of threads can change between frames, so always show this even if there currently is only one thread:
+        self.options.sorting.ui(ui);
 
         ui.separator();
 
